//--------------------------------------------------------------
// File     : main.c
// Datum    : 06.05.2015
// Version  : 1.0
// Autor    : UB
// EMail    : mc-4u(@)t-online.de
// Web      : www.mikrocontroller-4u.de
// CPU      : STM32F429
// Board    : STM32F429-Board von UB (Version 1.0)
// IDE      : CooCox CoIDE 1.7.4
// GCC      : 4.7 2012q4
// Module   : CMSIS_BOOT, M4_CMSIS_CORE
// Funktion : Hauptprogramm
// Hinweis  : Diese zwei Files muessen auf 8MHz stehen
//              "cmsis_boot/stm32f4xx.h"
//              "cmsis_boot/system_stm32f4xx.c"
// In Configuration diese Define hinzufgen :
// "STM32F429_439xx" , "__ASSEMBLY__" , "USE_STDPERIPH_DRIVER"
//--------------------------------------------------------------
// Beschreibung :
// LoLevel-Test vom eigenbau STM32F429-Board von UB (Version 1.0)
//
// test der 6 LEDs auf dem Board (zyklisches Lauflicht)
//
// Statusausgabe per COM-6 (3,3V UART) 115200 Baud
//--------------------------------------------------------------


#include "main.h"
#include "stm32_ub_led.h"
#include "stm32_ub_systick.h"
#include "stm32_ub_uart.h"

int main(void)
{
  uint8_t led_pos=0;
  uint16_t t_on=200, t_off=800; // ton,toff zeit in ms

  SystemInit(); // Quarz Einstellungen aktivieren

  // init vom Systick
  UB_Systick_Init();

  // init der uart
  UB_Uart_Init();

  // init der LEDs
  UB_Led_Init();

  // powerOn string
  UB_Uart_SendString(COM6,"F429-Board",CRLF);
  UB_Uart_SendString(COM6,"Led-Check",CRLF);

  // blinken aller LEDs
  while(1)
  {
    switch(led_pos) {
      case 0 :
        UB_Uart_SendString(COM6,"Led1",CRLF);
        UB_Led_On(LED1);
        UB_Systick_Pause_ms(t_on);
        UB_Led_Off(LED1);
        UB_Systick_Pause_ms(t_off);
        led_pos++;
      break;
      case 1 :
        UB_Uart_SendString(COM6,"Led2",CRLF);
        UB_Led_On(LED2);
        UB_Systick_Pause_ms(t_on);
        UB_Led_Off(LED2);
        UB_Systick_Pause_ms(t_off);
        led_pos++;
      break;
      case 2 :
        UB_Uart_SendString(COM6,"Led3",CRLF);
        UB_Led_On(LED3);
        UB_Systick_Pause_ms(t_on);
        UB_Led_Off(LED3);
        UB_Systick_Pause_ms(t_off);
        led_pos++;
      break;
      case 3 :
        UB_Uart_SendString(COM6,"Led4",CRLF);
        UB_Led_On(LED4);
        UB_Systick_Pause_ms(t_on);
        UB_Led_Off(LED4);
        UB_Systick_Pause_ms(t_off);
        led_pos++;
      break;
      case 4 :
        UB_Uart_SendString(COM6,"Led5",CRLF);
        UB_Led_On(LED5);
        UB_Systick_Pause_ms(t_on);
        UB_Led_Off(LED5);
        UB_Systick_Pause_ms(t_off);
        led_pos++;
      break;
      case 5 :
        UB_Uart_SendString(COM6,"Led6",CRLF);
        UB_Led_On(LED6);
        UB_Systick_Pause_ms(t_on);
        UB_Led_Off(LED6);
        UB_Systick_Pause_ms(t_off);
        led_pos=0;
      break;
    }
  }
}

